@@ -1,6 +1,7 @@
 from arc.middleware import Middleware
 from arc.errors import AppException
 import os
+import pathlib
 
 
 class DefaultMiddleware(Middleware):
@@ -17,5 +18,7 @@ class DefaultExceptionHandler:
 
     def handle_error(self, request, response, error):
         response.status_code = 500
-        response.body = self.app.custom_template(r"selfpages",
+        response.body = self.app.custom_template(pathlib.Path("selfpages").absolute(),
                                                  "index.html", context={"error": str(error)})
+
+error_404 = open(os.path.join(os.path.abspath(r"selfpages"), os.path.abspath(r"error-404.html")))
\ No newline at end of file
